# frozen_string_literal: true

module Jekyll
  module Filters
    # YAML to SCSS
    module YamlToScss
      # Converts a YAML object into SCSS.  Only supports one level
      # values.
      #
      # @param :yaml [Hash]
      # @return [String]
      def yaml_to_scss(yaml)
        yaml.map do |key, value|
          key = key_to_scss key

          case value
          when Array
            "$#{key}: (#{value.join(',')},);"
          when Hash
            values =
              value.map do |k, v|
                "\"#{key_to_scss k}\": #{v}"
              end

            "$#{key}: (#{values.join(',')},);"
          else
            "$#{key}: #{value};"
          end
        end.join("\n")
      end

      private

      # Dasherize key
      #
      # @param :key [String]
      # @return [String]
      def key_to_scss(key)
        key.tr '_', '-'
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::YamlToScss)
